==> opensearch-java-2.21.0-sources.jar: org/opensearch/client/opensearch/core/bulk/WriteOperation.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

package org.opensearch.client.opensearch.core.bulk;

import jakarta.json.stream.JsonGenerator;
import javax.annotation.Nullable;
import org.opensearch.client.json.JsonpDeserializer;
import org.opensearch.client.json.JsonpMapper;
import org.opensearch.client.json.ObjectDeserializer;

// typedef: _global.bulk.WriteOperation

public abstract class WriteOperation extends BulkOperationBase {

    @Nullable
    private final String pipeline;

    @Nullable
    private final Boolean requireAlias;

    // ---------------------------------------------------------------------------------------------

    protected WriteOperation(AbstractBuilder<?> builder) {
        super(builder);

        this.pipeline = builder.pipeline;
        this.requireAlias = builder.requireAlias;

    }

    @Nullable
    public final String pipeline() {
        return this.pipeline;
    }

    /**
     * API name: {@code require_alias}
     */
    @Nullable
    public final Boolean requireAlias() {
        return this.requireAlias;
    }

    protected void serializeInternal(JsonGenerator generator, JsonpMapper mapper) {

        super.serializeInternal(generator, mapper);
        if (this.pipeline != null) {
            generator.writeKey("pipeline");
            generator.write(this.pipeline);

        }
        if (this.requireAlias != null) {
            generator.writeKey("require_alias");
            generator.write(this.requireAlias);

        }

    }

    protected abstract static class AbstractBuilder<BuilderT extends AbstractBuilder<BuilderT>> extends BulkOperationBase.AbstractBuilder<
        BuilderT> {

        @Nullable
        private String pipeline;

        @Nullable
        private Boolean requireAlias;

        /**
         * API name: {@code pipeline}
         */
        public final BuilderT pipeline(@Nullable String value) {
            this.pipeline = value;
            return self();
        }

        /**
         * API name: {@code require_alias}
         */
        public final BuilderT requireAlias(@Nullable Boolean value) {
            this.requireAlias = value;
            return self();
        }

    }

    // ---------------------------------------------------------------------------------------------
    protected static <BuilderT extends AbstractBuilder<BuilderT>> void setupWriteOperationDeserializer(ObjectDeserializer<BuilderT> op) {
        BulkOperationBase.setupBulkOperationBaseDeserializer(op);
        op.add(AbstractBuilder::pipeline, JsonpDeserializer.stringDeserializer(), "pipeline");
        op.add(AbstractBuilder::requireAlias, JsonpDeserializer.booleanDeserializer(), "require_alias");

    }

}

==> opensearch-java-3.0.0-sources.jar: org/opensearch/client/opensearch/core/bulk/WriteOperation.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

package org.opensearch.client.opensearch.core.bulk;

import jakarta.json.stream.JsonGenerator;
import javax.annotation.Nullable;
import org.opensearch.client.json.JsonpDeserializer;
import org.opensearch.client.json.JsonpMapper;
import org.opensearch.client.json.ObjectDeserializer;

// typedef: _global.bulk.WriteOperation

public abstract class WriteOperation extends BulkOperationBase {

    @Nullable
    private final String pipeline;

    @Nullable
    private final Boolean requireAlias;

    // ---------------------------------------------------------------------------------------------

    protected WriteOperation(AbstractBuilder<?> builder) {
        super(builder);

        this.pipeline = builder.pipeline;
        this.requireAlias = builder.requireAlias;

    }

    @Nullable
    public final String pipeline() {
        return this.pipeline;
    }

    /**
     * API name: {@code require_alias}
     */
    @Nullable
    public final Boolean requireAlias() {
        return this.requireAlias;
    }

    protected void serializeInternal(JsonGenerator generator, JsonpMapper mapper) {

        super.serializeInternal(generator, mapper);
        if (this.pipeline != null) {
            generator.writeKey("pipeline");
            generator.write(this.pipeline);

        }
        if (this.requireAlias != null) {
            generator.writeKey("require_alias");
            generator.write(this.requireAlias);

        }

    }

    public abstract static class AbstractBuilder<BuilderT extends AbstractBuilder<BuilderT>> extends BulkOperationBase.AbstractBuilder<
        BuilderT> {

        @Nullable
        private String pipeline;

        @Nullable
        private Boolean requireAlias;

        /**
         * API name: {@code pipeline}
         */
        public final BuilderT pipeline(@Nullable String value) {
            this.pipeline = value;
            return self();
        }

        /**
         * API name: {@code require_alias}
         */
        public final BuilderT requireAlias(@Nullable Boolean value) {
            this.requireAlias = value;
            return self();
        }

    }

    // ---------------------------------------------------------------------------------------------
    protected static <BuilderT extends AbstractBuilder<BuilderT>> void setupWriteOperationDeserializer(ObjectDeserializer<BuilderT> op) {
        BulkOperationBase.setupBulkOperationBaseDeserializer(op);
        op.add(AbstractBuilder::pipeline, JsonpDeserializer.stringDeserializer(), "pipeline");
        op.add(AbstractBuilder::requireAlias, JsonpDeserializer.booleanDeserializer(), "require_alias");

    }

}
